@@ -798,7 +798,6 @@ on_response (GtkDialog       *dialog,
 	}
 }
 
-
 static void
 mateweather_pref_create (MateWeatherPref* pref)
 {
@@ -834,7 +833,6 @@ mateweather_pref_create (MateWeatherPref* pref)
 	GtkWidget* pref_find_hbox;
 	GtkWidget* image;
 
-
 	g_object_set (pref, "destroy-with-parent", TRUE, NULL);
 	gtk_window_set_title (GTK_WINDOW (pref), _("Weather Preferences"));
 	gtk_dialog_add_buttons (GTK_DIALOG (pref), "gtk-close", GTK_RESPONSE_CLOSE, "gtk-help", GTK_RESPONSE_HELP, NULL);
@@ -1037,15 +1035,15 @@ mateweather_pref_create (MateWeatherPref* pref)
 		}
 	#endif /* RADARMAP */
 
-    #ifdef HAVE_LIBNOTIFY
-		/* setup show-notifications button */
-		pref->priv->basic_show_notifications_btn = gtk_check_button_new_with_mnemonic (_("Show _notifications"));
+#ifdef HAVE_LIBNOTIFY
+	/* setup show-notifications button */
+	pref->priv->basic_show_notifications_btn = gtk_check_button_new_with_mnemonic (_("Show _notifications"));
 
-		if (!g_settings_is_writable (pref->priv->applet->settings, "show-notifications"))
-		{
-			hard_set_sensitive (pref->priv->basic_show_notifications_btn, FALSE);
-		}
-    #endif
+	if (!g_settings_is_writable (pref->priv->applet->settings, "show-notifications"))
+	{
+		hard_set_sensitive (pref->priv->basic_show_notifications_btn, FALSE);
+	}
+#endif
 
 	frame = create_hig_category (pref_basic_vbox, _("Update"));
 
@@ -1176,7 +1174,7 @@ mateweather_pref_create (MateWeatherPref* pref)
 #ifdef RADARMAP
     g_signal_connect (pref->priv->basic_radar_btn, "toggled", G_CALLBACK (on_radar_toggled), pref);
     g_signal_connect (pref->priv->basic_radar_url_btn, "toggled", G_CALLBACK (on_use_radar_url_toggled), pref);
-    g_signal_connect (pref->priv->basic_radar_url_entry, "focus_out_event", G_CALLBACK (on_radar_url_changed), pref);
+    g_signal_connect (pref->priv->basic_radar_url_entry, "focus-out-event", G_CALLBACK (on_radar_url_changed), pref);
 #endif /* RADARMAP */
 #ifdef HAVE_LIBNOTIFY
     g_signal_connect (pref->priv->basic_show_notifications_btn, "toggled", G_CALLBACK (on_show_notifications_toggled), pref);
