@@ -222,7 +222,6 @@ multiload_destroy_cb(GtkWidget *widget, gpointer data)
     return;
 }
 
-
 static gboolean
 multiload_button_press_event_cb (GtkWidget *widget, GdkEventButton *event, MultiloadApplet *ma)
 {
@@ -496,7 +495,9 @@ multiload_applet_new(MatePanelApplet *applet, const gchar *iid, gpointer data)
     ma->prop_dialog = NULL;
         ma->last_clicked = 0;
 
+#ifndef ENABLE_IN_PROCESS
     g_set_application_name (_("System Monitor"));
+#endif
 
     gtk_window_set_default_icon_name ("utilities-system-monitor");
 
@@ -534,15 +535,15 @@ multiload_applet_new(MatePanelApplet *applet, const gchar *iid, gpointer data)
 
     g_object_unref (action_group);
 
-    g_signal_connect (applet, "change_size",
+    g_signal_connect (applet, "change-size",
                       G_CALLBACK (multiload_change_size_cb), ma);
-    g_signal_connect (applet, "change_orient",
+    g_signal_connect (applet, "change-orient",
                       G_CALLBACK (multiload_change_orient_cb), ma);
     g_signal_connect (applet, "destroy",
                       G_CALLBACK (multiload_destroy_cb), ma);
-    g_signal_connect (applet, "button_press_event",
+    g_signal_connect (applet, "button-press-event",
                       G_CALLBACK (multiload_button_press_event_cb), ma);
-    g_signal_connect (applet, "key_press_event",
+    g_signal_connect (applet, "key-press-event",
                       G_CALLBACK (multiload_key_press_event_cb), ma);
 
     atk_obj = gtk_widget_get_accessible (GTK_WIDGET (applet));
@@ -576,8 +577,8 @@ multiload_factory (MatePanelApplet *applet,
     return retval;
 }
 
-MATE_PANEL_APPLET_OUT_PROCESS_FACTORY ("MultiLoadAppletFactory",
-                                       PANEL_TYPE_APPLET,
-                                       "multiload",
-                                       multiload_factory,
-                                       NULL)
+PANEL_APPLET_FACTORY ("MultiLoadAppletFactory",
+                      PANEL_TYPE_APPLET,
+                      "multiload",
+                      multiload_factory,
+                      NULL)
